#!/bin/bash

# Import configuration file

source /etc/ntechs/zbx_bacula.conf

function discovery {

	local list
	local ctrlist=`$bconsole <<EOF | tail -n+6 | head -n-1 
@output /dev/null
messages
@output
.clients
quit
EOF`
	[ "$?" != "0" ] && return

	local ifs_backup=$IFS
	IFS=$'\n'

  for line in $ctrlist; do
		list="$list,"'{"{#CLNAME}":"'${line}'"}'
	done;

	IFS="$ifs_backup"

	echo -n '{"data":['${list#,}']}'
}

function jobs-discovery {

	local list
	local ctrlist=`$bconsole <<EOF | grep ^Job:
@output /dev/null
messages
@output
show jobs
quit
EOF`
	[ "$?" != "0" ] && return

	local ifs_backup=$IFS
	IFS=$'\n'

  for line in $ctrlist; do
		[[ "$line" =~ JobType=66 ]] && list="$list,"'{"{#JNAME}":"'$(echo "$line" | sed 's/^.*name=\(.*\)\sJobType.*$/\1/')'"}'
	done;

	IFS="$ifs_backup"

	echo -n '{"data":['${list#,}']}'
}

function get-last-job-id() {
	local JobName=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select max(JobId) from Job where Name='$JobName';

quit
EOF`

}

function get-last-job-status() {
	local JobName=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select JobStatus from Job where Type='B' and JobId=(select max(JobId) from Job where Name='$JobName');

quit
EOF`

}

function get-last-job-level() {
	local JobName=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select Level from Job where Type='B' and JobId=(select max(JobId) from Job where Name='$JobName');

quit
EOF`

}

function get-last-job-files() {
	local JobName=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select JobFiles from Job where Type='B' and JobId=(select max(JobId) from Job where Name='$JobName');

quit
EOF`

}

function get-last-job-bytes() {
	local JobName=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select JobBytes from Job where Type='B' and JobId=(select max(JobId) from Job where Name='$JobName');

quit
EOF`

}

function get-jobs-count-by-status() {
	local Status=$1
	echo `$bconsole <<EOF | tail -n+15 | head -n-4 | sed "s/|\s\|\|\s|//g" 
@output /dev/null
messages
@output
sqlquery
select count(JobId) from Job where Type='B' and JobStatus='$Status';

quit
EOF`

}

function send-job-info() {

	echo `whoami` >> /tmp/zbx-bacula.log
	
	local JobId=$1
	local ctrlist=`$bconsole <<EOF | tail -n+15 | head -n-4
@output /dev/null
messages
@output
sqlquery
select Name,JobStatus,Level,JobFiles,JobBytes,EndTime,JobErrors from Job where JobId='$JobId';

quit
EOF`
	
	local ifs_backup=$IFS
	IFS=$'|'
	arr=($ctrlist)
	IFS="$ifs_backup"

	local JobName=$(echo -e "${arr[1]}" | sed "s/^\s\(.*\)\s$/\1/")

	local return=0

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,jobid]" -o $JobId >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+1)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,status]" -o ${arr[2]//[[:blank:]]/} >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+2)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,level]" -o ${arr[3]//[[:blank:]]/} >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+4)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,files]" -o ${arr[4]//[^[:digit:]]/} >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+8)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,bytes]" -o ${arr[5]//[^[:digit:]]/} >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+16)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,finished]" -o "`echo ${arr[6]} | sed 's/^ *\(.+\) *$/\1/'`" >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+32)) ; fi

	$zabbixSender -z $zabbixSrvAddr -p $zabbixSrvPort -s $baculaHostName -k "bacula.job[$JobName,errors]" -o ${arr[7]//[^[:digit:]]/} >/dev/null 2>&1
	if [ $? -ne 0 ] ; then return=$(($return+64)) ; fi

	[ "$return" != "0" ] && echo 'Error: '$return
	exit $return
}

function usage() {
	echo "${0##*/} command"
	echo " Commands available:"
	echo "   discovery"
	echo "   jobs-discovery"
	echo "   get-last-job-id <JobName>"
	echo "   get-last-job-status <JobName>"
	echo "   get-last-job-level <JobName>"
	echo "   get-last-job-files <JobName>"
	echo "   get-last-job-bytes <JobName>"
	echo "   get-jobs-count-by-status <Status>"
	echo "   send-job-info <JobId>"
	exit 1
}

# Chose what to do
case $1 in
  discovery)
		[ $# -ne 1 ] && usage
		discovery
		;;
  jobs-discovery)
		[ $# -ne 1 ] && usage
		jobs-discovery
		;;
  get-last-job-id)
		[ $# -ne 2 ] && usage
		get-last-job-id "$2"
		;;
  get-last-job-status)
		[ $# -ne 2 ] && usage
		get-last-job-status "$2"
		;;
  get-last-job-level)
		[ $# -ne 2 ] && usage
		get-last-job-level "$2"
		;;
  get-last-job-files)
		[ $# -ne 2 ] && usage
		get-last-job-files "$2"
		;;
  get-last-job-bytes)
		[ $# -ne 2 ] && usage
		get-last-job-bytes "$2"
		;;
  get-jobs-count-by-status)
		[ $# -ne 2 ] && usage
		get-jobs-count-by-status "$2"
		;;
  send-job-info)
		[ $# -ne 2 ] && usage
		send-job-info "$2"
		;;
  *)
		usage
		;;
esac

exit 0

